@@ -100,6 +100,8 @@ CivisFuture <- function(expr = NULL,
 }
 
 #' @export
+#' @param future CivisFuture object.
+#' @describeIn CivisFuture Run a CivisFuture
 run.CivisFuture <- function(future, ...) {
   if (is.null(future$job$containerId)) {
     cargo <- c(expr = future$expr, envir = future$envir,
@@ -118,6 +120,7 @@ run.CivisFuture <- function(future, ...) {
 }
 
 #' @export
+#' @describeIn CivisFuture Return the value of a CivisFuture
 value.CivisFuture <- function(future, ...) {
   if (future$state == "created") {
     future <- run(future)
@@ -140,7 +143,7 @@ value.CivisFuture <- function(future, ...) {
 }
 
 #' Cancel the evaluation of a CivisFuture.
-#' @param future CivisFuture object to be cancelled.
+#' @param future CivisFuture object.
 #' @param ... unused for CivisFuture.
 #' @export
 cancel <- function(future, ...) {
@@ -148,12 +151,14 @@ cancel <- function(future, ...) {
 }
 
 #' @export
+#' @describeIn CivisFuture Cancel a CivisFuture
 cancel.CivisFuture <- function(future, ...) {
   scripts_delete_containers_runs(id = future$job$containerId, run_id = future$job$id)
   future$state <- "cancelled"
 }
 
 #' @export
+#' @describeIn CivisFuture Check if a CivisFutre has resolved
 resolved.CivisFuture <- function(future, ...){
   if (!is.null(future$job$containerId)) {
     future$state <- scripts_get_containers_runs(id = future$job$containerId,
@@ -163,7 +168,9 @@ resolved.CivisFuture <- function(future, ...){
 }
 
 #' @export
-fetch_logs.CivisFuture <- function(object, limit, ...){
+#' @param object CivisFuture
+#' @describeIn CivisFuture Fetch logs from a CivisFuture
+fetch_logs.CivisFuture <- function(object, ...){
   object$logs
 }
 
